@@ -49,6 +49,12 @@ def get_mimetype_from_filename(filename):
         return 'application/octet-stream'
 
 
+def load_rels_int(rels_int_path):
+    with open(rels_int_path, 'rb') as rels_int_file:
+        rels_int_bytes = rels_int_file.read()
+    return ET.fromstring(rels_int_bytes)
+
+
 def get_download_filename_from_rels_int(rels_int_root, pid, filepath):
     if rels_int_root:
         for description in rels_int_root.findall('rdf:Description', RELS_INT_NS):
@@ -58,6 +64,10 @@ def get_download_filename_from_rels_int(rels_int_root, pid, filepath):
                         return os.path.basename(child.text)
 
 
+def get_file_size(full_path):
+    return os.stat(full_path).st_size
+
+
 def object_path(pid):
     sha256_checksum = hashlib.sha256(pid.encode('utf8')).hexdigest()
     return os.path.join(
@@ -166,6 +176,7 @@ class Object:
         if not self._inventory['versions'][self.head_version]['state']:
             raise ObjectDeleted()
         self._files_info = None
+        self._rels_int_root = None
 
     @staticmethod
     def reversed_version_numbers(head_version):
@@ -196,13 +207,6 @@ class Object:
 
     def _get_files_info(self):
         info = {}
-        try:
-            rels_int_path = self.get_path_to_file('RELS-INT')
-            with open(rels_int_path, 'rb') as rels_int_file:
-                rels_int_bytes = rels_int_file.read()
-            rels_int_root = ET.fromstring(rels_int_bytes)
-        except FileNotFoundError:
-            rels_int_root = None
         for checksum, filepaths in self._inventory['versions'][self.head_version]['state'].items():
             for filepath in filepaths:
                 if filepath not in info:
@@ -211,9 +215,9 @@ class Object:
                             'checksum': checksum,
                             'checksum_type': 'SHA-512',
                             'state': 'A',
-                            'size': os.stat(os.path.join(self.object_path, self._inventory['manifest'][checksum][0])).st_size,
+                            'size': get_file_size(os.path.join(self.object_path, self._inventory['manifest'][checksum][0])),
                         }
-                    download_filename = get_download_filename_from_rels_int(rels_int_root, self.pid, filepath)
+                    download_filename = get_download_filename_from_rels_int(self.rels_int_root, self.pid, filepath)
                     if not download_filename:
                         download_filename = filepath
                     mimetype = get_mimetype_from_filename(download_filename)
@@ -247,9 +251,19 @@ class Object:
     def last_modified(self):
         return utc_datetime_from_string(self._inventory['versions'][self.head_version]['created'])
 
+    @property
+    def rels_int_root(self):
+        if not self._rels_int_root:
+            try:
+                rels_int_path = self.get_path_to_file('RELS-INT')
+                self._rels_int_root = load_rels_int(rels_int_path)
+            except FileNotFoundError:
+                self._rels_int_root = None
+        return self._rels_int_root
+
     def get_path_to_file(self, filename, version=None):
         if not version:
-            version = list(self._inventory['versions'].keys())[-1]
+            version = self._inventory['head']
         for checksum, files in self._inventory['versions'][version]['state'].items():
             for f in files:
                 if f == filename:
